[−][src]Enum sequoia_openpgp::KeyHandle
Enum representing an identifier for certificates and keys.
A KeyHandle contains either a Fingerprint or a KeyID.
This is needed because signatures can reference their issuer
either by Fingerprint or by KeyID.
Currently, sequoia supports version 4 fingerprints and Key ID only. Version 3 fingerprints and Key ID were deprecated by RFC 4880 in 2007.
A v4 fingerprint is, essentially, a 20-byte SHA-1 hash over the key's public key packet. A v4 Key ID is defined as the fingerprint's lower 8 bytes.
For the exact definition, see Section 12.2 of RFC 4880.
Both fingerprint and Key ID are used to identify a key, e.g., the issuer of a signature.
Examples
use openpgp::KeyHandle; use openpgp::Packet; use openpgp::parse::Parse; let p = Packet::from_bytes( "-----BEGIN PGP SIGNATURE----- // ... -----END PGP SIGNATURE-----")?; if let Packet::Signature(sig) = p { let issuers = sig.get_issuers(); assert_eq!(issuers.len(), 2); assert_eq!(&issuers[0], &KeyHandle::Fingerprint( "C03F A641 1B03 AE12 5764 6118 7223 B566 78E0 2528" .parse()?)); assert_eq!(&issuers[1], &KeyHandle::KeyID("7223 B566 78E0 2528".parse()?)); } else { unreachable!("It's a signature!"); }
Variants
Fingerprint(Fingerprint)A Fingerprint.
KeyID(KeyID)A KeyID.
Implementations
impl KeyHandle[src]
pub fn as_bytes(&self) -> &[u8][src]
Returns the raw identifier as a byte slice.
pub fn aliases<H>(&self, other: H) -> bool where
H: Borrow<KeyHandle>, [src]
H: Borrow<KeyHandle>,
Returns whether self and other could be aliases of each
other.
KeyHandle's PartialEq implementation cannot assert that a
Fingerprint and a KeyID are equal, because distinct
fingerprints may have the same KeyID, and PartialEq must
be transitive, i.e.,
a == b and b == c implies a == c.
That is, if fpr1 and fpr2 are distinct fingerprints with the
same key ID then:
fpr1 == keyid and fpr2 == keyid, but fpr1 != fpr2.
In these cases (and only these cases) KeyHandle's
PartialOrd implementation returns None to correctly
indicate that a comparison is not possible.
This definition of equality makes searching for a given
KeyHandle using PartialEq awkward. This function fills
that gap. It answers the question: given two KeyHandles,
could they be aliases? That is, it implements the desired,
non-transitive equality relation:
// fpr1 and fpr2 are different fingerprints with the same KeyID. assert!(! fpr1.eq(&fpr2)); assert!(fpr1.aliases(&keyid)); assert!(fpr2.aliases(&keyid)); assert!(! fpr1.aliases(&fpr2));