pub struct NotationData { /* private fields */ }Expand description
Payload of a Notation Data subpacket.
The Notation Data subpacket provides a mechanism for a
message’s signer to insert nearly arbitrary data into the
signature. Because notations can be marked as critical, it is
possible to add security relevant notations, which the receiving
OpenPGP implementation will respect (in the sense that an
implementation will reject signatures that include unknown,
critical notations), even if they don’t understand the notations
themselves.
It is possible to control how Sequoia’s higher-level functionality
handles unknown, critical notations using a Policy object.
Depending on the degree of control required, it may be sufficient
to customize a StandardPolicy object using, for instance, the
StandardPolicy::good_critical_notations method.
Notation names are human-readable UTF-8 strings. There are two
namespaces: The user namespace and the IETF namespace. Names in
the user namespace have the form name@example.org and are
managed by the owner of the domain. Names in the IETF namespace
may not contain an @ and are managed by IANA. See Section
5.2.3.24 of RFC 9580 for details.
Implementations
Sourceimpl NotationData
impl NotationData
Sourcepub fn new<N, V, F>(name: N, value: V, flags: F) -> Self
pub fn new<N, V, F>(name: N, value: V, flags: F) -> Self
Creates a new Notation Data subpacket payload.
Sourcepub fn flags(&self) -> &NotationDataFlags
pub fn flags(&self) -> &NotationDataFlags
Returns the flags.