#[non_exhaustive]pub enum AsymmetricAlgorithm {
Show 32 variants
RSA1024,
RSA2048,
RSA3072,
RSA4096,
ElGamal1024,
ElGamal2048,
ElGamal3072,
ElGamal4096,
DSA1024,
DSA2048,
DSA3072,
DSA4096,
NistP256,
NistP384,
NistP521,
BrainpoolP256,
BrainpoolP384,
BrainpoolP512,
Cv25519,
X25519,
X448,
Ed25519,
Ed448,
EdDSA,
MLDSA65_Ed25519,
MLDSA87_Ed448,
SLHDSA128s,
SLHDSA128f,
SLHDSA256s,
MLKEM768_X25519,
MLKEM1024_X448,
Unknown,
}Expand description
Asymmetric encryption algorithms.
This type is for refining the StandardPolicy with respect to
asymmetric algorithms. In contrast to PublicKeyAlgorithm, it
does not concern itself with the use (encryption or signing), and
it does include key sizes (if applicable) and elliptic curves.
Key sizes put into are buckets, rounding down to the nearest
bucket. For example, a 3253-bit RSA key is categorized as
RSA3072.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
RSA1024
RSA with key sizes up to 2048-1 bit.
RSA2048
RSA with key sizes up to 3072-1 bit.
RSA3072
RSA with key sizes up to 4096-1 bit.
RSA4096
RSA with key sizes larger or equal to 4096 bit.
ElGamal1024
ElGamal with key sizes up to 2048-1 bit.
ElGamal2048
ElGamal with key sizes up to 3072-1 bit.
ElGamal3072
ElGamal with key sizes up to 4096-1 bit.
ElGamal4096
ElGamal with key sizes larger or equal to 4096 bit.
DSA1024
DSA with key sizes up to 2048-1 bit.
DSA2048
DSA with key sizes up to 3072-1 bit.
DSA3072
DSA with key sizes up to 4096-1 bit.
DSA4096
DSA with key sizes larger or equal to 4096 bit.
NistP256
NIST curve P-256.
NistP384
NIST curve P-384.
NistP521
NIST curve P-521.
BrainpoolP256
brainpoolP256r1.
BrainpoolP384
brainpoolP384r1.
BrainpoolP512
brainpoolP512r1.
Cv25519
D.J. Bernstein’s Curve25519.
X25519
X25519 (RFC 7748).
X448
X448 (RFC 7748).
Ed25519
Ed25519 (RFC 8032).
Ed448
Ed448 (RFC 8032).
EdDSA
EdDSA (v4 Ed25519Legacy)
MLDSA65_Ed25519
Composite signature algorithm using ML-DSA-65 and Ed25519.
MLDSA87_Ed448
Composite signature algorithm using ML-DSA-87 and Ed448.
SLHDSA128s
SLH-DSA signature algorithm 128 bit, small signatures.
SLHDSA128f
SLH-DSA signature algorithm 128 bit, fast signatures.
SLHDSA256s
SLH-DSA signature algorithm 256 bit, small signatures.
MLKEM768_X25519
Composite KEM using ML-KEM-768 and X25519.
MLKEM1024_X448
Composite KEM using ML-KEM-1024 and X448.
Unknown
Unknown algorithm.
Implementations
Sourceimpl AsymmetricAlgorithm
impl AsymmetricAlgorithm
Sourcepub fn variants() -> impl Iterator<Item = AsymmetricAlgorithm>
pub fn variants() -> impl Iterator<Item = AsymmetricAlgorithm>
Returns an iterator over all valid variants.
Returns an iterator over all known variants. This does not
include the AsymmetricAlgorithm::Unknown variant.